@@ -5,7 +5,7 @@ use Email::Valid::Loose;
 use Dwarf::Util qw/encode_utf8 decode_utf8/;
 use Image::Info qw/image_type/;
 use JSON;
-use MIME::Base64 qw(decode_base64);
+use MIME::Base64 qw(decode_base64 decoded_base64_length);
 use Scalar::Util qw/looks_like_number/;
 
 
@@ -22,8 +22,43 @@ rule NOT_BLANK => sub {
 	$_ ne "";
 };
 
-rule INT  => sub { $_ =~ /\A[+\-]?[0-9]+\z/ };
-rule UINT => sub { $_ =~ /\A[0-9]+\z/       };
+rule INT  => sub {
+	return 0 unless $_ =~ /\A[+\-]?[0-9]+\z/;
+	return 0 unless $_ < 2_147_483_647;
+	return 0 unless $_ > -2_147_483_648;
+	return 1;
+};
+
+rule UINT => sub {
+	return 0 unless $_ =~ /\A[0-9]+\z/;
+	return 0 unless $_ < 2_147_483_647;
+	return 1;
+};
+
+rule BIGINT => sub {
+	return 0 unless $_ =~ /\A[+\-]?[0-9]+\z/;
+	return 1 if $_ =~ /\A[+\-]?[0-9]{1,18}\z/;
+	return 1 if $_ =~ /\A[+]?[0-9]{20,}\z/;
+	return 1 if $_ =~ /\A[\-]?[0-9]{20,}\z/;
+	Math::BigInt->use or die;
+	my $MIN = Math::BigInt->new("-9223372036854775808");
+	my $MAX = Math::BigInt->new("9223372036854775807");
+	my $val = Math::BigInt->new($_);
+	return 0 if $MIN->bcmp($val) > 0;
+	return 0 if $val->bcmp($MAX) > 0;
+	return 1;
+};
+
+rule BIGUINT => sub {
+	return 0 unless $_ =~ /\A[0-9]+\z/;
+	return 1 if $_ =~ /\A[0-9]{1,18}\z/;
+	return 1 if $_ =~ /\A[0-9]{20,}\z/;
+	Math::BigInt->use or die;
+	my $MAX = Math::BigInt->new("9223372036854775807");
+	my $val = Math::BigInt->new($_);
+	return 0 if $val->bcmp($MAX) > 0;
+	return 1;
+};
 
 rule NUMBER => sub {
 	my $value = $_;
@@ -200,6 +235,10 @@ rule JSON => sub {
 	return 1;
 };
 
+rule CREDITCARD_NUMBER   => sub { $_ =~ /\A[0-9]{14,16}\z/ };
+rule CREDITCARD_EXPIRE   => sub { $_ =~ /^\d{2}\/\d{2}$/ };
+rule CREDITCARD_SECURITY => sub { $_ =~ /\A[0-9]{3,4}\z/ };
+
 rule BASE64_TYPE => sub {
 	Carp::croak('missing args. usage: ["BASE64_TYPE", "(jpeg|png|gif)"]') unless @_;
 	my $expected = $_[0];
@@ -215,6 +254,14 @@ rule BASE64_TYPE => sub {
 	return $filetype =~ /^$expected$/i;
 };
 
+rule BASE64_SIZE => sub {
+	Carp::croak('missing args. usage: ["BASE64_SIZE", "10000"]') unless @_;
+	my $expected = $_[0];
+	my $length = decoded_base64_length($_);
+	return $length < $expected;
+};
+
+
 file_rule FILE_NOT_NULL => sub {
 	return 0 if not defined($_);
 	return 0 if $_ eq "";
